@@ -49,13 +49,17 @@
     <script>
         var lineArr = [[116.478935, 39.997761, "2020-10-02 00:02:38\uff1a\u901f\u5ea646km/h"], [116.478939, 39.997825], [116.478912, 39.998549], [116.478912, 39.998549], [116.478998, 39.998555], [116.478998, 39.998555], [116.479282, 39.99856], [116.479658, 39.998528, "fdafasfdasfasf"], [116.480151, 39.998453], [116.480784, 39.998302], [116.480784, 39.998302], [116.481149, 39.998184], [116.481573, 39.997997], [116.481863, 39.997846], [116.482072, 39.997718], [116.482362, 39.997718, "fdafasfdasfasf"], [116.483633, 39.998935, "fdafasfdasfasf"], [116.48367, 39.998968, "fdafasfdasfasf"], [116.484648, 39.999861, "2020-10-02 00:02:38\uff1a\u901f\u5ea646km/h"]];
         var tripList = [3, 5, 10, 15];
-        var markerArr = [[116.478998, 39.998555], [116.478998, 39.998555]];
+        var markerSet = [{"data":[[116.478998, 39.998555], [116.478998, 39.998555],[116.48367, 39.998968, "fdafasfdasfasf"], [116.484648, 39.999861, "2020-10-02 00:02:38\uff1a\u901f\u5ea646km/h"]],"img":"https://a.amap.com/jsapi_demos/static/demo-center/icons/poi-marker-red.png"}];
         // extends
         var massArr = lineArr.concat([]);
-        var tripArr=[];
-        for (i=0;i<tripList.length;i++){
-            tripArr[i]=lineArr[tripList[i]];
-        }
+        var tripArr = getTripArr(tripList);
+        function getTripArr(tripList){
+            var _data=[];
+            for (i=0;i<tripList.length;i++){
+                _data[i]=lineArr[tripList[i]];
+            }
+            return _data
+        };
     </script>
 
     // main_container
@@ -63,7 +67,7 @@
         // function initContainer(){
         var map = new AMap.Map("container", {
             resizeEnable: true,
-            center: lineArr.concat(markerArr)[0],
+            center: lineArr.concat(markerSet[0].data)[0].slice(0.2),
             zoom: 17
         });
 
@@ -91,12 +95,26 @@
 
     // trip_marker
     <script>
+        var zoomStyleMapping1 = { 3:0,4:0,5:0,6:0,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:0,16:0,17:0,18:0,19:0,20:0 }
         var infoWindow = new AMap.InfoWindow({offset: new AMap.Pixel(0, -30)});
         for (var i = 0; i < tripArr.length; i++) {
             var _curData = tripArr[i];
-            var _marker = new AMap.Marker({
+            var _marker = new AMap.ElasticMarker({
                 position: _curData.slice(0,2),
-                map: map
+                zooms:[3,20],
+                styles:[{
+                    icon:{
+                        img:'https://a.amap.com/jsapi_demos/static/demo-center/icons/poi-marker-default.png',
+                        size:[26,36],//可见区域的大小
+                        ancher:[13,36],//锚点
+                        fitZoom:13,//最合适的级别
+                        scaleFactor:1.1,//地图放大一级的缩放比例系数
+                        maxScale:1,//最大放大比例
+                        minScale:0.5//最小放大比例
+                    }
+                }],
+                zoomStyleMapping:zoomStyleMapping1,
+                map:map
             });
             _marker.content= (i+1).toString()+". "+_curData.slice(2,).toString();
             _marker.on('click', markerClick);
@@ -105,17 +123,25 @@
             infoWindow.setContent(e.target.content);
             infoWindow.open(map, e.target.getPosition());
         };
+
     </script>
 
+
     // trajectory moving
     <script>
+        var marker_visible=false
+        if (lineArr.length>0)
+        {
+            marker_visible=true
+        };
         var marker_moving = new AMap.Marker({
             map: map,
             position: lineArr[0],
             icon: "https://webapi.amap.com/images/car.png",
             offset: new AMap.Pixel(-26, -13),
             autoRotation: true,
-            angle:-90
+            angle:-90,
+            visible:marker_visible,
         });
 
         // 全部轨迹
@@ -244,71 +270,42 @@
 
     // markerArr
     <script>
+        var zoomStyleMapping1 = { 3:0,4:0,5:0,6:0,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:0,16:0,17:0,18:0,19:0,20:0 }
         var infoWindow2 = new AMap.InfoWindow({offset: new AMap.Pixel(0, -30)});
-        for (var i = 0; i < markerArr.length; i++) {
-            var _curData = markerArr[i];
-            var _marker = new AMap.Marker({
-                position: _curData.slice(0,2),
-                icon:'//a.amap.com/jsapi_demos/static/demo-center/icons/poi-marker-red.png',
-                map: map
-            });
-            _marker.content= _curData.slice(2,).toString();
-            _marker.on('click', markerClick);
-        }
+
+        for (var i = 0; i < markerSet.length; i++) {
+            var markerArr = markerSet[i].data;
+            var markerImg = markerSet[i].img;
+            for (var j = 0; j < markerArr.length; j++) {
+                var _curData = markerArr[j];
+                var marker = new AMap.ElasticMarker({
+                    position:_curData.slice(0,2),
+                    zooms:[3,20],
+                    styles:[{
+                        icon:{
+                            img:markerImg,
+                            size:[26,36],//可见区域的大小
+                            ancher:[13,36],//锚点
+                            fitZoom:13,//最合适的级别
+                            scaleFactor:1.1,//地图放大一级的缩放比例系数
+                            maxScale:1,//最大放大比例
+                            minScale:0.5//最小放大比例
+                        }
+                    }],
+                    zoomStyleMapping:zoomStyleMapping1,
+                    map:map
+                })
+                marker.content= _curData.slice(2,).toString();
+                marker.on('click', markerClick);
+            };
+        };
         function markerClick(e) {
             infoWindow2.setContent(e.target.content);
             infoWindow2.open(map, e.target.getPosition());
         };
+
     </script>
 
-    // 灵活标记点大小
-    <!-- <script>
-        var zoomStyleMapping = {
-                14:0,
-                15:0,
-                16:1,
-                17:1,
-                18:1,
-                19:1,
-                20:1
-        }
-        var infoWindow2 = new AMap.InfoWindow({offset: new AMap.Pixel(0, -30)});
-        for (var i = 0; i < markerArr.length; i++) {
-            var _curData = markerArr[i];
-            var marker = new AMap.ElasticMarker({
-                position:_curData.slice(0,2),
-            styles:[{
-                    icon:{
-                        img:'https://webapi.amap.com/theme/v1.3/markers/n/mark_b.png',
-                        size:[16,16],//可见区域的大小
-                        ancher:[8,16],//锚点
-                        fitZoom:14,//最合适的级别
-                        scaleFactor:1,//地图放大一级的缩放比例系数
-                    }
-                },{
-                    icon:{
-                        img:'https://webapi.amap.com/theme/v1.3/markers/n/mark_b.png',
-                        size:[6,6],
-                        ancher:[8,16],//锚点
-                        fitZoom:17.5,
-                        scaleFactor:1.2,
-                        maxScale:2,
-                        minScale:0.125
-                    }
-                }],
-            zoomStyleMapping:zoomStyleMapping
-        })
-        map.add(marker);
-        _marker.content= _curData.slice(2,).toString();
-        _marker.on('click', markerClick);
-    };
-    function markerClick(e) {
-            infoWindow2.setContent(e.target.content);
-            infoWindow2.open(map, e.target.getPosition());
-        };
-
-    </script> -->
-
     <script>
             map.setFitView();
     </script>
